summaryrefslogtreecommitdiff
path: root/packet_states.h
diff options
context:
space:
mode:
authorChris Kuethe <chris.kuethe@gmail.com>2006-11-02 00:14:38 +0000
committerChris Kuethe <chris.kuethe@gmail.com>2006-11-02 00:14:38 +0000
commitf14c20f3545fd3bcdf3d77c9fba8871d93da2027 (patch)
tree1df4da219deeec239cca9c06e8670201ca55aa88 /packet_states.h
parent3f4fb28fa5b947c65cb865651a7fd5ae79244674 (diff)
downloadgpsd-f14c20f3545fd3bcdf3d77c9fba8871d93da2027.tar.gz
making italk have a better chance of working. at least it detects packets now.
Diffstat (limited to 'packet_states.h')
-rw-r--r--packet_states.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/packet_states.h b/packet_states.h
index 8fad28f0..8f6c174f 100644
--- a/packet_states.h
+++ b/packet_states.h
@@ -71,11 +71,11 @@
#ifdef ITALK_ENABLE
ITALK_LEADER_1, /* saw leading < of iTalk packet */
- ITALK_LEADER_2, /* saw leading * of iTalk packet */
- ITALK_LENGTH_1, /* saw MSB of packet length */
- ITALK_LENGTH_2, /* saw LSB of packet length */
+ ITALK_LEADER_2, /* saw leading ! of iTalk packet */
+ ITALK_LENGTH, /* saw packet length */
+ ITALK_PAYLOAD, /* in payload part of iTalk Packet */
ITALK_DELIVERED, /* seen end of payload */
- ITALK_TRAILER_1, /* saw iTalk trailer byte */
+ ITALK_TRAILER, /* saw iTalk trailer byte */
ITALK_RECOGNIZED, /* found end of the iTalk packet */
#endif /* ITALK_ENABLE */